Platform project
================

The **Platform** project configures the hardware of the evaluation board
and is a CMSIS-RTOS2 based software template that can be further expanded.

RTOS: Keil RTX5 Real-Time Operating System
------------------------------------------

The real-time operating system [Keil RTX5](https://arm-software.github.io/CMSIS_5/RTOS2/html/rtx5_impl.html) implements the resource management.

It is configured with the following settings:

- [Global Dynamic Memory size](https://arm-software.github.io/CMSIS_5/RTOS2/html/config_rtx5.html#systemConfig): 24000 bytes
- [Default Thread Stack size](https://arm-software.github.io/CMSIS_5/RTOS2/html/config_rtx5.html#threadConfig): 3072 bytes
- [Event Recorder Configuration](https://arm-software.github.io/CMSIS_5/RTOS2/html/config_rtx5.html#evtrecConfig)
  - [Global Initialization](https://arm-software.github.io/CMSIS_5/RTOS2/html/config_rtx5.html#evtrecConfigGlobIni): 1
    - Start Recording: 1

Refer to [Configure RTX v5](https://arm-software.github.io/CMSIS_5/RTOS2/html/config_rtx5.html) for a detailed description of all configuration options.

Board: NXP S32K3X4EVB-Q172
--------------------------

The tables below list the device configuration for this board. The board layer for the NXP MIMXRT1064-EVK is using the software component `::Board Support: SDK Project Template: project_template (Variant: evkmimxrt1064)` from `NXP.EVK-MIMXRT1064_BSP.12.3.0` pack.

The heap/stack setup and the CMSIS-Driver assignment is in configuration files of related software components.

The example project can be re-configured to work on custom hardware. Refer to ["Configuring Example Projects with MCUXpresso Config Tools"](https://github.com/MDK-Packs/Documentation/tree/master/Using_MCUXpresso) for information.

### System Configuration

| System Component        | Setting
|:------------------------|:----------------------------------------
| Device                  | S32K344
| Board                   | S32K3X4EVB-Q172
| Heap                    | 64 kB (configured in linker script S32K3xx.sct file)
| Stack (MSP)             |  1 kB (configured in linker script S32K3xx.sct file)

### Clock Configuration

| Clock                   | Setting
|:------------------------|:----------------------------------------
| FIRC                    |  48 MHz
| CORE_CLK                |  48 MHz

### GPIO Configuration and usage

| GPIO        | Signal / Label | GPIO Settings               | Usage
|:------------|:---------------|:----------------------------|:-----
| PTB19       | vioBUTTON0     | Input Mode                  | User Button SW6
| PTB26       | vioBUTTON1     | Input Mode                  | User Button SW5
| PTA29       | vioLED0        | Output Mode                 | RGBLED red
| PTA30       | vioLED1        | Output Mode                 | RGBLED green
| PTA31       | vioLED2        | Output Mode                 | RGBLED blue

### CMSIS-Driver mapping

| CMSIS-Driver VIO  | Physical board hardware
|:------------------|:-----------------------
| vioBUTTON0        | User Button SW6 (USER_SW1)
| vioBUTTON1        | User Button SW5 (USER_SW0 disabled)
| vioLED0           | RGBLED red
| vioLED1           | RGBLED green
| vioLED2           | RGBLED blue
